Skip to main content

coveragepy-lcov

coveragepy-lcov is a simple CLI for converting .coverage files generated by Coverage.py to the LCOV format.

Credits

This tools is based on code from Coverage.py.

Installation

Using pip:

pip install coveragepy-lcov

Usage

# If the .coverage file is in your current working directory
coveragepy-lcov

# Point to a different .coverage file path
coveragepy-lcov --data_file_path example/.coverage

# Write the output to a different file path
coveragepy-lcov --output_file_path build/lcov.info

# Use relative paths in the LCOV output
coveragepy-lcov --relative_path

Options

Usage: coveragepy-lcov [OPTIONS]

Options:
  --data_file_path TEXT    Path to .coverage file
  --output_file_path TEXT  lcov.info output file path
  --config_file TEXT       Path to .coveragerc file
  --relative_path          Use relative path in LCOV output
  --preview                Preview LCOV output
  --help                   Show this message and exit.

Further reading

Metadata

Release files for coveragepy-lcov 0.1.2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for coveragepy-lcov 0.1.2
File Size Uploaded
coveragepy-lcov-0.1.2.tar.gz 6.8 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for coveragepy-lcov 0.1.2
File Interpreter ABI Platform
coveragepy_lcov-0.1.2-py3-none-any.whl Python 3 none any Details

Total release size: 14.4 kB

Release files / coveragepy-lcov-0.1.2.tar.gz

Download URL coveragepy-lcov-0.1.2.tar.gz
Size 6.8 kB
Tags Source
SHA-256 checksum
How to use checksums
db6ad0d255d3a8041d30e797a9ec69c77c5963694a6b02a00907b56db7b882a3
BLAKE2b-256 checksum
How to use checksums
10feb61fc3223fcbb19eddd642104b65957768904b42d90f98500e76f43a489a
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.13 CPython/3.6.15 Linux/5.11.0-1028-azure

Release files / coveragepy_lcov-0.1.2-py3-none-any.whl

Download URL coveragepy_lcov-0.1.2-py3-none-any.whl
Size 7.7 kB
Tags Python 3
SHA-256 checksum
How to use checksums
7c1e454ada324a1f47fd7cd2de2c6349b9822cc79691b313ed10370e7ce1b08b
BLAKE2b-256 checksum
How to use checksums
8806041799881505228efdd8916f798211d73ef0950dcd12d2beb2ef596c011a
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.13 CPython/3.6.15 Linux/5.11.0-1028-azure

Release history Release notifications | RSS feed

This release

0.1.2 This release

2 release files

0.1.1

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page